@@ -15,10 +15,12 @@ pub struct SponsoredMessage {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Unique sponsored message identifier
-  id: i64,
-  /// Chat identifier
+  /// Message identifier; unique for the chat to which the sponsored message belongs among both ordinary and sponsored messages
+  message_id: i64,
+  /// Sponsor chat identifier; 0 if the sponsor chat is accessible through an invite link
   sponsor_chat_id: i64,
+  /// Information about the sponsor chat; may be null unless sponsor_chat_id == 0
+  sponsor_chat_info: Option<ChatInviteLinkInfo>,
   /// An internal link to be opened when the sponsored message is clicked; may be null. If null, the sponsor chat needs to be opened instead
   link: Option<InternalLinkType>,
   /// Content of the message. Currently, can be only of the type messageText
@@ -43,10 +45,12 @@ impl SponsoredMessage {
     RTDSponsoredMessageBuilder { inner }
   }
 
-  pub fn id(&self) -> i64 { self.id }
+  pub fn message_id(&self) -> i64 { self.message_id }
 
   pub fn sponsor_chat_id(&self) -> i64 { self.sponsor_chat_id }
 
+  pub fn sponsor_chat_info(&self) -> &Option<ChatInviteLinkInfo> { &self.sponsor_chat_info }
+
   pub fn link(&self) -> &Option<InternalLinkType> { &self.link }
 
   pub fn content(&self) -> &MessageContent { &self.content }
@@ -62,8 +66,8 @@ impl RTDSponsoredMessageBuilder {
   pub fn build(&self) -> SponsoredMessage { self.inner.clone() }
 
    
-  pub fn id(&mut self, id: i64) -> &mut Self {
-    self.inner.id = id;
+  pub fn message_id(&mut self, message_id: i64) -> &mut Self {
+    self.inner.message_id = message_id;
     self
   }
 
@@ -74,6 +78,12 @@ impl RTDSponsoredMessageBuilder {
   }
 
    
+  pub fn sponsor_chat_info<T: AsRef<ChatInviteLinkInfo>>(&mut self, sponsor_chat_info: T) -> &mut Self {
+    self.inner.sponsor_chat_info = Some(sponsor_chat_info.as_ref().clone());
+    self
+  }
+
+   
   pub fn link<T: AsRef<InternalLinkType>>(&mut self, link: T) -> &mut Self {
     self.inner.link = Some(link.as_ref().clone());
     self
